diff --git a/org.fortiss.tooling.base.ui/trunk/icons/overlay/ellipse-reflections.png b/org.fortiss.tooling.base.ui/trunk/icons/overlay/ellipse-reflections.png
deleted file mode 100644
index 1aceeffcc70ea56b0112100f1db06e579b64fb58..0000000000000000000000000000000000000000
Binary files a/org.fortiss.tooling.base.ui/trunk/icons/overlay/ellipse-reflections.png and /dev/null differ
diff --git a/org.fortiss.tooling.base.ui/trunk/icons/overlay/linear-blend-round.png b/org.fortiss.tooling.base.ui/trunk/icons/overlay/linear-blend-round.png
deleted file mode 100644
index 655dba892742ff937ac9e2c52371445ce57ca900..0000000000000000000000000000000000000000
Binary files a/org.fortiss.tooling.base.ui/trunk/icons/overlay/linear-blend-round.png and /dev/null differ
diff --git a/org.fortiss.tooling.base.ui/trunk/icons/overlay/radial-blend.png b/org.fortiss.tooling.base.ui/trunk/icons/overlay/radial-blend.png
deleted file mode 100644
index 660c0cef02162e057ce2c4a262f261472a6a1a87..0000000000000000000000000000000000000000
Binary files a/org.fortiss.tooling.base.ui/trunk/icons/overlay/radial-blend.png and /dev/null differ
diff --git a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/command/ReconnectCommand.java b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/command/ReconnectCommand.java
index 8840b6cb1d89be961c5a29eb0e8f939847b62461..ceac76af54d18d93e82ff403ad58952e0a98a7ae 100644
--- a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/command/ReconnectCommand.java
+++ b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/command/ReconnectCommand.java
@@ -31,7 +31,7 @@ import org.fortiss.tooling.kernel.service.IConnectionCompositorService;
  * @author hoelzl
  * @author $Author$
  * @version $Rev$
- * @ConQAT.Rating RED Hash: 014CBB9569896D0AA2554DE850E8F91E
+ * @ConQAT.Rating YELLOW Hash: 24421D2AC104331D9746EEAF90095300
  */
 public class ReconnectCommand extends ConnectCommand {
 
@@ -53,10 +53,7 @@ public class ReconnectCommand extends ConnectCommand {
 			return false;
 		}
 		if (context.getSource().getModel() instanceof EObject
-				&& context.getTarget().getModel() instanceof EObject
-				// TODO @review CD: why check source's parent? - C&P from
-				// Connect?
-				&& context.getSource().getParent().getModel() instanceof EObject) {
+				&& context.getTarget().getModel() instanceof EObject) {
 			return IConnectionCompositorService.INSTANCE.canReconnect(
 					connection, (EObject) context.getSource().getModel(),
 					(EObject) context.getTarget().getModel(), context);
diff --git a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/figure/PrettyInsetEllipse.java b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/figure/PrettyInsetEllipse.java
index 4a69cc4898585a678f139490d55ba81dce4c7a51..bfb328f708d3d7ae2e2b6ec9ae1fb2d307ce69e0 100644
--- a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/figure/PrettyInsetEllipse.java
+++ b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/figure/PrettyInsetEllipse.java
@@ -24,9 +24,7 @@ import org.eclipse.draw2d.geometry.Insets;
 import org.eclipse.draw2d.geometry.Rectangle;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Color;
-import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.Path;
-import org.eclipse.ui.plugin.AbstractUIPlugin;
 
 /**
  * This shape consists of an ellipse that is surrounded by transparent insets.
@@ -40,23 +38,13 @@ import org.eclipse.ui.plugin.AbstractUIPlugin;
  * @author hoelzl
  * @author $Author$
  * @version $Rev$
- * @ConQAT.Rating RED Hash: D7A97336995AA26EEDBC95C2B49127FA
+ * @ConQAT.Rating YELLOW Hash: 7E86CA664B6B561EE22AEC45CC29C1E2
  */
 public class PrettyInsetEllipse extends Shape {
 
 	/** The transparent insets surrounding this shape. */
 	protected final Insets insets;
 
-	// TODO @review CD: overlay images as well as "fancy" look are currently
-	// omitted. corresponding
-	// preference seems to have disappeared.
-	// -> clean up or re-enable
-
-	/** A complete set of reflections for 3 dimensional ellipses. */
-	protected static final Image reflections = AbstractUIPlugin
-			.imageDescriptorFromPlugin("org.fortiss.tooling.base.ui",
-					"icons/overlay/ellipse-reflections.png").createImage();
-
 	/** Constructor. */
 	public PrettyInsetEllipse(Insets insets) {
 		this.insets = insets;
@@ -70,49 +58,19 @@ public class PrettyInsetEllipse extends Shape {
 	 */
 	@Override
 	protected void fillShape(Graphics gfx) {
-		EVisualStyle style = EVisualStyle.get();
 		gfx.pushState();
 		Rectangle croppedBounds = getCroppedBounds();
-		if (style == EVisualStyle.Glossy) {
-			// Glossy style.
-			gfx.setBackgroundColor(ColorConstants.black);
-			gfx.setAntialias(SWT.ON);
-			gfx.setAlpha(48);
-			gfx.fillOval(croppedBounds.getCopy().translate(5, 5));
-			gfx.restoreState();
-			if (getBackgroundColor().getGreen() < 255) {
-				gfx.setBackgroundColor(ColorConstants.red);
-			} else {
-				gfx.setBackgroundColor(ColorConstants.orange);
-			}
-			gfx.fillOval(croppedBounds);
-			gfx.setForegroundColor(ColorConstants.yellow);
-			gfx.setAlpha(180);
 
-			Path path = new Path(null);
-			path.addArc(croppedBounds.x, croppedBounds.y, croppedBounds.width,
-					croppedBounds.height, 0, 360);
-			gfx.setClip(path);
-			gfx.fillGradient(croppedBounds, true);
-			gfx.restoreState();
-			path.dispose();
+		// Traditional style is default.
+		gfx.fillOval(croppedBounds);
+		gfx.setForegroundColor(ColorConstants.white);
+		gfx.setAlpha(200);
 
-			gfx.setAntialias(SWT.ON);
-			gfx.setAlpha(220);
-			gfx.drawImage(reflections, new Rectangle(reflections.getBounds()),
-					croppedBounds);
-		} else {
-			// Traditional style is default.
-			gfx.fillOval(croppedBounds);
-			gfx.setForegroundColor(ColorConstants.white);
-			gfx.setAlpha(200);
-
-			Path path = new Path(null);
-			path.addArc(croppedBounds.x, croppedBounds.y, croppedBounds.width,
-					croppedBounds.height, 0, 360);
-			gfx.setClip(path);
-			gfx.fillGradient(croppedBounds, true);
-		}
+		Path path = new Path(null);
+		path.addArc(croppedBounds.x, croppedBounds.y, croppedBounds.width,
+				croppedBounds.height, 0, 360);
+		gfx.setClip(path);
+		gfx.fillGradient(croppedBounds, true);
 		gfx.popState();
 	}
 
diff --git a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/figure/PrettyRoundedRectangle.java b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/figure/PrettyRoundedRectangle.java
index e912a0871d2ca27e5b3b2282d14a08cd01e4f25d..f6c6a4b0b52e12a84656f8b0ab06d194c60b9cba 100644
--- a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/figure/PrettyRoundedRectangle.java
+++ b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/figure/PrettyRoundedRectangle.java
@@ -24,8 +24,6 @@ import org.eclipse.draw2d.geometry.Insets;
 import org.eclipse.draw2d.geometry.Rectangle;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Color;
-import org.eclipse.swt.graphics.Image;
-import org.fortiss.tooling.base.ui.ToolingBaseUIActivator;
 
 /**
  * This shape consists of a rounded rectangle that is surrounded by transparent
@@ -38,7 +36,7 @@ import org.fortiss.tooling.base.ui.ToolingBaseUIActivator;
  * @author hoelzl
  * @author $Author$
  * @version $Rev$
- * @ConQAT.Rating RED Hash: 31CAA5E0D8A786AECB929587261F1199
+ * @ConQAT.Rating YELLOW Hash: 34D4F4B5FBB7A3565AE4065D4D7EFED2
  */
 public class PrettyRoundedRectangle extends Shape {
 
@@ -48,20 +46,6 @@ public class PrettyRoundedRectangle extends Shape {
 	/** The transparent insets surrounding this shape. */
 	protected final Insets insets;
 
-	// TODO @review CD: overlay images as well as "fancy" look are currently
-	// omitted. corresponding
-	// preference seems to have disappeared.
-	// -> clean up or re-enable
-
-	/** A linear blend applied at the top. */
-	protected static final Image linearBlend = ToolingBaseUIActivator
-			.getImageDescriptor("icons/overlay/linear-blend-round.png")
-			.createImage();
-
-	/** A radial blend applied at the bottom. */
-	protected static final Image radialBlend = ToolingBaseUIActivator
-			.getImageDescriptor("icons/overlay/radial-blend.png").createImage();
-
 	/** Constructor. */
 	public PrettyRoundedRectangle(int cornerRadius, Insets insets) {
 		this.cornerRadius = cornerRadius;
@@ -71,34 +55,12 @@ public class PrettyRoundedRectangle extends Shape {
 	/** {@inheritDoc} */
 	@Override
 	protected void fillShape(Graphics gfx) {
-		EVisualStyle style = EVisualStyle.get();
 		gfx.pushState();
-		if (style == EVisualStyle.Glossy) {
-			// Glossy style.
-			final Rectangle b = getCroppedBounds();
-			gfx.setBackgroundColor(ColorConstants.black);
-			gfx.setAlpha(48);
-			gfx.fillRoundRectangle(b.getCopy().translate(5, 5), cornerRadius,
-					cornerRadius);
-			gfx.restoreState();
-			gfx.fillRoundRectangle(b, cornerRadius, cornerRadius);
-			gfx.setAlpha(255);
-			gfx.drawImage(linearBlend, new Rectangle(linearBlend.getBounds()),
-					b.getCopy().resize(-1, -b.height / 2 - 1));
-			gfx.setAlpha(200);
-			gfx.drawImage(
-					radialBlend,
-					new Rectangle(radialBlend.getBounds()),
-					b.getCopy().resize(-1, -b.height / 2 - 1)
-							.translate(0, b.height / 2));
-		} else {
-			// Traditional style is default.
-			gfx.fillRoundRectangle(getCroppedBounds(), cornerRadius,
-					cornerRadius);
-			gfx.setForegroundColor(ColorConstants.white);
-			gfx.setAlpha(200);
-			gfx.fillGradient(getCroppedBounds().resize(0, -cornerRadius), true);
-		}
+		// Traditional style is default.
+		gfx.fillRoundRectangle(getCroppedBounds(), cornerRadius, cornerRadius);
+		gfx.setForegroundColor(ColorConstants.white);
+		gfx.setAlpha(200);
+		gfx.fillGradient(getCroppedBounds().resize(0, -cornerRadius), true);
 		gfx.popState();
 	}
 
diff --git a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/DiagramLayoutEditPolicy.java b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/DiagramLayoutEditPolicy.java
index a204bf278e6b8bae7019bb831f6aa16c59a0626c..8c2bda19fc96f5204d91a51596b2e3443bc6e8a7 100644
--- a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/DiagramLayoutEditPolicy.java
+++ b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/DiagramLayoutEditPolicy.java
@@ -39,7 +39,7 @@ import org.fortiss.tooling.base.ui.editpart.command.MoveWithinDiagramCommand;
  * @author hoelzl
  * @author $Author$
  * @version $Rev$
- * @ConQAT.Rating RED Hash: FF45F874E12A71D06C92F154DF319D98
+ * @ConQAT.Rating YELLOW Hash: DC3E049397CBC5F1BA2B9181C1B6C9B7
  */
 public class DiagramLayoutEditPolicy extends RelayCreateCommandEditPolicyBase {
 
@@ -63,7 +63,6 @@ public class DiagramLayoutEditPolicy extends RelayCreateCommandEditPolicyBase {
 		return super.getCommand(request);
 	}
 
-	// TODO @review CD: clone with ElementLayoutEditPolicy -> move to superclass
 	/** {@inheritDoc} */
 	@Override
 	protected Command getMoveChildrenCommand(final Request request) {
diff --git a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/ElementLayoutEditPolicy.java b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/ElementLayoutEditPolicy.java
index f6f67464524df5aef5a2c4ed11d2b05e5222c1f4..6904920a1fef9a7f67e8b1d2ab8ac75d4121a2cb 100644
--- a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/ElementLayoutEditPolicy.java
+++ b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/ElementLayoutEditPolicy.java
@@ -39,7 +39,7 @@ import org.fortiss.tooling.kernel.model.INamedCommentedElement;
  * @author hoelzl
  * @author $Author$
  * @version $Rev$
- * @ConQAT.Rating RED Hash: E074E4EB7529C3D44215580F3AAB6932
+ * @ConQAT.Rating YELLOW Hash: F419FCA55F52F78F6EB0C7D80AF32627
  */
 public class ElementLayoutEditPolicy<T extends ILayoutedModelElement & INamedCommentedElement>
 		extends RelayCreateCommandEditPolicyBase {
@@ -63,7 +63,6 @@ public class ElementLayoutEditPolicy<T extends ILayoutedModelElement & INamedCom
 		return new NonResizableEditPolicy();
 	}
 
-	// TODO @review CD: clone with ElementLayoutEditPolicy -> move to superclass
 	/** {@inheritDoc} */
 	@Override
 	protected Command getMoveChildrenCommand(Request request) {
diff --git a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/RelayCreateCommandEditPolicyBase.java b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/RelayCreateCommandEditPolicyBase.java
index 6637e8627343ab1166e6c321784419b494a8d44c..9fb6005f0fdda75405d562fea9db4de008f3e5cb 100644
--- a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/RelayCreateCommandEditPolicyBase.java
+++ b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/editpart/policy/RelayCreateCommandEditPolicyBase.java
@@ -43,7 +43,7 @@ import org.fortiss.tooling.kernel.ui.dnd.ElementCompositionSource;
  * @author hoelzl
  * @author $Author$
  * @version $Rev$
- * @ConQAT.Rating RED Hash: 0D7A3CEE777E39AE87521E2458B76977
+ * @ConQAT.Rating YELLOW Hash: 66E79A7E8FC55B782B9141E8473B8A7B
  */
 public abstract class RelayCreateCommandEditPolicyBase extends LayoutEditPolicy {
 
@@ -69,7 +69,8 @@ public abstract class RelayCreateCommandEditPolicyBase extends LayoutEditPolicy
 	 * {@link CreateConnectionCompositionRequest}s.
 	 */
 	private Command getCreateCompositionCommand(CreateRequest request) {
-		// TODO @review CD: sure? if(NEQ null) return null ?
+		// the request should only contain a position (e.g. mouse clicked not
+		// dragged)
 		if (request.getSize() != null) {
 			return null;
 		}
diff --git a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/properties/view/PropertySectionWithCopyPasteBase.java b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/properties/view/PropertySectionWithCopyPasteBase.java
index e49deaa0c414520d15a87481f99ba64d5ad33740..a59d9b1ca9cf4391f28a49fafdec0e26a11d81d8 100644
--- a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/properties/view/PropertySectionWithCopyPasteBase.java
+++ b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/properties/view/PropertySectionWithCopyPasteBase.java
@@ -18,8 +18,8 @@ $Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
 package org.fortiss.tooling.base.ui.properties.view;
 
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
-import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
@@ -32,10 +32,10 @@ import org.fortiss.tooling.kernel.ui.extension.base.PropertySectionBase;
  * @author ratiu
  * @author $Author: hoelzl $
  * @version $Rev: 18709 $
- * @ConQAT.Rating RED Hash: 658C6CE7721FC82AA7DF76FC0A1CE6F0
+ * @ConQAT.Rating YELLOW Hash: 28164A1500812F5F071D29F4ECBD38B9
  */
 public abstract class PropertySectionWithCopyPasteBase<T extends IModelElementSpecification>
-		extends PropertySectionBase implements SelectionListener {
+		extends PropertySectionBase {
 
 	/** Widget for clip board copy. */
 	protected Button clipboardCopy;
@@ -53,36 +53,30 @@ public abstract class PropertySectionWithCopyPasteBase<T extends IModelElementSp
 		copyPasteComposite.setLayout(new FillLayout(SWT.HORIZONTAL));
 		clipboardCopy = getWidgetFactory().createButton(copyPasteComposite,
 				"copy", SWT.PUSH);
-		clipboardCopy.addSelectionListener(this);
+		clipboardCopy.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				setClipboardSpec(specification);
+				clipboardPaste.setEnabled(false);
+			}
+		});
 		clipboardPaste = getWidgetFactory().createButton(copyPasteComposite,
 				"paste", SWT.PUSH);
-		clipboardPaste.addSelectionListener(this);
+		clipboardPaste.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				if (getClipboardSpec() != null
+						&& getClipboardSpec() != specification) {
+					doPerformCopy();
+					setClipboardSpec(null);
+					clipboardPaste.setEnabled(false);
+				}
+			}
+		});
 		clipboardPaste.setEnabled(false);
 		createFormEntry(copyPasteComposite, "Clipboard");
 	}
 
-	// TODO @review CD: why not use SelectionAdapter and thus save the empty
-	// method?
-	/** {@inheritDoc} */
-	@Override
-	public void widgetDefaultSelected(SelectionEvent e) {
-		// nothing to do
-	}
-
-	/** {@inheritDoc} */
-	@Override
-	public void widgetSelected(SelectionEvent e) {
-		if (e.widget == clipboardCopy) {
-			setClipboardSpec(specification);
-			clipboardPaste.setEnabled(false);
-		} else if (e.widget == clipboardPaste && getClipboardSpec() != null
-				&& getClipboardSpec() != specification) {
-			doPerformCopy();
-			setClipboardSpec(null);
-			clipboardPaste.setEnabled(false);
-		}
-	}
-
 	/** Performs the copy. */
 	protected abstract void doPerformCopy();
 
diff --git a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/tablecell/CheckBoxLabelProvider.java b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/tablecell/CheckBoxLabelProvider.java
index d423859c8692bd9ddcb911d4e229c2ca93278e90..6657d3d78e6fed49f3f94e80b36cf5d67f23ed2b 100644
--- a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/tablecell/CheckBoxLabelProvider.java
+++ b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/tablecell/CheckBoxLabelProvider.java
@@ -38,13 +38,10 @@ import org.eclipse.swt.widgets.Shell;
  * @author hoelzl
  * @author $Author$
  * @version $Rev$
- * @ConQAT.Rating RED Hash: 74220EAB8C4432DC0ABDACC754751490
+ * @ConQAT.Rating YELLOW Hash: 1879A8B4DD69C9B0CA8F5E9C62920F71
  */
-
-// TODO @review CD: Very interesting, but is this really necessary? Don't SWT
-// checkboxes work as good or even better? During testing these checkboxes seem
-// to react slower and additionally they have an ugly gray background.
-
+// Using drawn images may seem strange, but internet sources could not provide
+// any other solution to having checkbox in cell editors
 public abstract class CheckBoxLabelProvider extends ColumnLabelProvider {
 	/** {@link JFaceResources} id for checked image. */
 	private static final String CHECKED_KEY = "CHECKED";
diff --git a/org.fortiss.tooling.kernel/trunk/plugin.properties b/org.fortiss.tooling.kernel/trunk/plugin.properties
new file mode 100644
index 0000000000000000000000000000000000000000..eccaa80b4b70bb525df2baa9731ecd5c2e716fa1
--- /dev/null
+++ b/org.fortiss.tooling.kernel/trunk/plugin.properties
@@ -0,0 +1,4 @@
+# (c) 2011 ForTISS GmbH
+
+pluginName = Model Model
+providerName = www.example.org
diff --git a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/tablecell/DecoratedIconNameLabelProvider.java b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/tablecell/IconNameLabelProvider.java
similarity index 86%
rename from org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/tablecell/DecoratedIconNameLabelProvider.java
rename to org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/tablecell/IconNameLabelProvider.java
index 81ce0bf4bb4a4def8dc665bc5f3fac31c30480f7..45785f5c18f73c8c2e0e759c497ded31877d9c2c 100644
--- a/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/tablecell/DecoratedIconNameLabelProvider.java
+++ b/org.fortiss.tooling.base.ui/trunk/src/org/fortiss/tooling/base/ui/tablecell/IconNameLabelProvider.java
@@ -19,6 +19,7 @@ package org.fortiss.tooling.base.ui.tablecell;
 
 import org.eclipse.emf.ecore.EObject;
 import org.eclipse.jface.viewers.CellLabelProvider;
+import org.eclipse.jface.viewers.DecoratingStyledCellLabelProvider;
 import org.eclipse.jface.viewers.DelegatingStyledCellLabelProvider.IStyledLabelProvider;
 import org.eclipse.jface.viewers.ILabelProviderListener;
 import org.eclipse.jface.viewers.StyledString;
@@ -27,18 +28,16 @@ import org.fortiss.tooling.kernel.model.INamedElement;
 import org.fortiss.tooling.kernel.ui.service.IModelElementHandlerService;
 
 /**
  * {@link CellLabelProvider} for {@link INamedElement} with decoration. Name and
  * icon are obtained from {@link IModelElementHandlerService}.
  * 
  * @author hoelzl
  * @author $Author$
  * @version $Rev$
- * @ConQAT.Rating RED Hash: 358A7180C7CC44420271B76CD80E8450
+ * @ConQAT.Rating YELLOW Hash: CA5333015D50B981971B61CD6B9D5B89
  */
-
-// TODO @review CD: Imprecise class name. I expected elements with error/warning
-// decorations rather than simply an icon.
-public class DecoratedIconNameLabelProvider implements IStyledLabelProvider {
+public class IconNameLabelProvider implements IStyledLabelProvider {
 	/** {@inheritDoc} */
 	@Override
 	public void removeListener(ILabelProviderListener listener) {
@@ -27,18 +28,16 @@ import org.fortiss.tooling.kernel.model.INamedElement;
 
 /**
- * {@link CellLabelProvider} for {@link INamedElement} with decoration. Name and
- * icon are obtained from {@link IModelElementHandlerService}.
+ * {@link CellLabelProvider} for {@link INamedElement} to be used with
+ * {@link DecoratingStyledCellLabelProvider}. Name and icon are obtained from
+ * {@link IModelElementHandlerService}.
  * 
  * @author hoelzl